@@ -3,16 +3,14 @@
 #2) Should we have more options for pedigrees? For now, if custom pedigree is specified for one
 #pedigree, custom must also be specified for the other pedigree
 #3) Files must have '.' as decimal separator
-#4) Change dropout windows to gedit?
-#5) Contributors must be the same under both hypotheses. Their familiy relationship can be changed with
-#   the pedigree, but any reference profiles must be the same under both hypotheses
+#4) All individuals must be represented in all pedigrees
 
 relMixGUI <- function(){
   
   options("guiToolkit"="tcltk")
-
+  
   #Files must have '.' as decimal separator
-  tableReader <- function(filename) { #helpfunction
+  tableReader <- function(filename) {
     tab <- read.table(filename,header=TRUE,sep="\t",stringsAsFactors=FALSE,na.strings=c(NA,""))
     tryCatch( {  if(ncol(tab)==1) tab <- read.table(filename,header=TRUE,sep=",",stringsAsFactors=FALSE,na.strings=c(NA,"")) } ,error=function(e) e)
     tryCatch( {  if(ncol(tab)==1) tab <- read.table(filename,header=TRUE,sep=";",stringsAsFactors=FALSE,na.strings=c(NA,"")) } ,error=function(e) e)
@@ -23,7 +21,7 @@ relMixGUI <- function(){
   tableWriter <- function(filename,obj){
     write.table(obj,file=filename,sep="\t",row.names=FALSE,quote=FALSE)
   }
-
+  
   f_importprof <- function(h,...) {
     type=h$action #get type of profile
     proffile = gfile(text=paste("Open ",type," file",sep=""),type="open",
@@ -34,10 +32,10 @@ relMixGUI <- function(){
   
   f_export <- function(obj) {
     savefile = gfile(text=paste("Save file as",sep=""),type="save", initialfilename = "LR.txt")
-                     #filter=list("text"=list(patterns=list("*.txt","*.csv","*.tab")),"all"=list(patterns=list("*")))
+    #filter=list("text"=list(patterns=list("*.txt","*.csv","*.tab")),"all"=list(patterns=list("*")))
     tableWriter(savefile,obj) #load profile
   }
-
+  
   #Make pedigree
   f_pedigree <- function(h,...){
     if(svalue(h$obj)=="Paternity"){
@@ -98,7 +96,7 @@ relMixGUI <- function(){
   #   assign(paste("ped",h$action,sep=""),ped1,envir=mmTK)
   #   assign(paste("persons_ped",h$action,sep=""),persons,envir=mmTK)
   # }
-
+  
   #Get values from object and assign to new object in mmTK environment
   f_values <- function(h,...) {
     r <- svalue(h$obj)
@@ -112,7 +110,7 @@ relMixGUI <- function(){
       dispose(h$obj)
     })
   }
-
+  
   #Makes pop-up window for database
   f_database <- function(h,...){
     freqWindow <- gwindow("Frequency database",visible=FALSE)
@@ -143,24 +141,27 @@ relMixGUI <- function(){
     
     visible(freqWindow) <- TRUE
   }
-
-
+  
+  
   #Makes pop-up window to fill in mutation details
   f_mutations <- function(h,...){
     mutWindow <- gwindow("Mutations",visible=FALSE)
     mutGroup2 <- ggroup(horizontal = TRUE, container=mutWindow,spacing=7)
     mutFrame2 <- gframe("Mutation model",container=mutGroup2)
     mutFrame3 <- gframe("Range",container=mutGroup2)
+    mutPar <- get('mutPar',mmTK)
     #Range window
-    objRange <- gedit('0.5', width=4, container=mutFrame3)
+    objRange <- gedit(mutPar$mutRange, width=4, container=mutFrame3)
     enabled(objRange) <- FALSE
     #Common male and female mutation model
-    objMutModel <- gcombobox(c("Equal","Proportional","Stepwise"), selected=1,
-                              container=mutFrame2, handler=function(h,...) {
-                               assign("Mut",svalue(h$obj),envir=mmTK)
-                               #Range will not be used unless model is Stepwise
-                               assign("range1",0.5,envir=mmTK)
-                               f_changeMutation(svalue(h$obj),objRange)})
+    Mut <- get('Mut',mmTK)
+    mutModels <- c("Equal","Proportional","Stepwise")
+    comboMut <- gcombobox(mutModels, selected=which(mutModels==Mut),
+                          container=mutFrame2, handler=function(h,...) {
+                            #assign("Mut",svalue(h$obj),envir=mmTK)
+                            #Range will not be used unless model is Stepwise
+                            #assign("range1",mutPar$mutRange,envir=mmTK)
+                            f_changeMutation(svalue(h$obj),objRange)})
     #List to store parameters in
     objMut <- vector('list',3)
     names(objMut) <- c("mutRange","fMutRate","mMutRate")
@@ -168,13 +169,16 @@ relMixGUI <- function(){
     mutFrame4 <- gframe("Mutation rates",container=mutWindow,horizontal=TRUE)
     #Separate male and female mutation rates
     glabel("Female",container=mutFrame4)
-    objMut[[2]] <- gedit('0', width=5, container=mutFrame4)
+    objMut[[2]] <- gedit(mutPar$fMutRate, width=5, container=mutFrame4)
     glabel("Male",container=mutFrame4)
-    objMut[[3]] <- gedit('0', width=5,container=mutFrame4)
-    saveButton <- gbutton(text = "Save", handler = function(h,...) saveParameters(objMut,mutWindow,"mutPar"),container=mutWindow)
+    objMut[[3]] <- gedit(mutPar$mMutRate, width=5,container=mutFrame4)
+    saveButton <- gbutton(text = "Save", ,container=mutWindow, handler = function(h,...) {
+      assign("Mut",svalue(comboMut),envir=mmTK)
+      saveParameters(objMut,mutWindow,"mutPar")}
+    )
     visible(mutWindow) <- TRUE
   }
-
+  
   #Set mutation model
   f_changeMutation <- function(mutMod,objRange){
     if(mutMod=="Stepwise"){ #If stepwise, also give option to give a mutation range
@@ -197,49 +201,63 @@ relMixGUI <- function(){
     #  assign(paste(h$action,"Mat",sep=""),MM,envir=mmTK)
     #}
   }
-
+  
   #Makes option pop-up window to fill in theta and silent alleles
   f_options <- function(h,...){
+    optPar <- get("optPar",mmTK)
     optWindow <- gwindow("Options",visible=FALSE)
     optGroup <- ggroup(horizontal = TRUE, container=optWindow,spacing=7)
     #Theta
     glabel("Theta",container=optGroup)
     objOpt <- vector('list',3)
     names(objOpt) <- c("theta","silent","MAF")
-    objOpt[[1]] <- gedit('0', width=5, container=optGroup)
+    objOpt[[1]] <- gedit(optPar$theta, width=5, container=optGroup)
     #Silent allele
     glabel("Silent allele frequency",container=optGroup)
-    objOpt[[2]] <- gedit('0', width=5, container=optGroup)
+    objOpt[[2]] <- gedit(optPar$silent, width=5, container=optGroup)
     #Minimum allele frequency
     glabel("Min. allele frequency",container=optGroup)
-    objOpt[[3]] <- gedit('0.001', width=5, container=optGroup)
-    saveButton <- gbutton(text = "ok", ,container=optWindow, handler = function(h,...){
+    objOpt[[3]] <- gedit(optPar$MAF, width=5, container=optGroup)
+    saveButton <- gbutton(text = "Save", ,container=optWindow, handler = function(h,...){
       saveParameters(objOpt,optWindow,"optPar")
     })
     visible(optWindow) <- TRUE
   }
-
+  
   #Makes pop-up window to fill in dropout values per contributor and drop-in
   f_dropout <- function(h,...){
-    dropWindow <- gwindow("Dropout and drop-in",visible=FALSE)
+    dropWindow <- gwindow("Dropout and drop-in",width=500,visible=FALSE)
     #Get pedigree data
-    if(!exists("idxC",envir=mmTK)){
+    if(!exists("idxC1",envir=mmTK)){
       f_errorWindow("Specify contributors first")
     }
     dropFrame2 <- gframe("Dropout for each contributor",container=dropWindow)
     #Get contributors
-    idxC <- get("idxC",envir=mmTK)
+    dropliste <- get("dropliste",envir=mmTK)
+    #Get default values/values that have already been specified
+    #idxC <- get("idxC",envir=mmTK)
+    idxC1 <- get("idxC1",envir=mmTK)
+    idxC2 <- get("idxC2",envir=mmTK)
+    idxC <- union(idxC1,idxC2)
+    #If dropliste has not been updated yet, it contains only one default dropout value 
+    #and a drop-in value. Set the default dropout value for all contributors
+    #if(length(dropliste)==2) dropliste <- c(rep(dropliste[1],length(idxC)),dropliste[2])
+    dropNames <- names(dropliste)
     objDrop <- list()
     for(i in 1:length(idxC)){
       g <- glabel(idxC[i], container=dropFrame2,horizontal=FALSE)
-      objDrop[[i]] <- gspinbutton(0,1,by=0.01, value=0,container=dropFrame2)
+      #objDrop[[i]] <- gspinbutton(0,1,by=0.01, default=dropliste[[i]],container=dropFrame2)
+      #Check if a dropout value is already specified, if not set to 0
+      val <- ifelse(idxC[i]%in%dropNames,dropliste[[which(dropNames==idxC[i])]],0)
+      objDrop[[i]] <- gedit(format(val,digits=4),width=4,container=dropFrame2)
     }
     dropinFrame <- gframe("Drop-in",container=dropWindow)
-    objDrop[[length(idxC)+1]] <- gspinbutton(0,1,by=0.01, value=0,digits=3,container=dropinFrame)
+    #objDrop[[length(dropliste)]] <- gspinbutton(0,1,by=0.01, value=dropliste[[length(dropliste)]],digits=3,container=dropinFrame)
+    objDrop[[length(idxC)+1]] <- gedit(format(dropliste[[length(dropliste)]],digits=4),width=4,container=dropinFrame)
     names(objDrop) <- c(idxC,"dropin")
-    saveButton <- gbutton(text = "ok",container=dropWindow, handler = function(h,...) {
+    saveButton <- gbutton(text = "Save",container=dropWindow, handler = function(h,...) {
       saveParameters(objDrop,dropWindow,"dropliste")
-      })
+    })
     visible(dropWindow) <- TRUE
   }
   #Save button
@@ -256,7 +274,7 @@ relMixGUI <- function(){
     assign(varName,values,envir=mmTK)
     dispose(window)
   }
-
+  
   f_contributors <- function(h,...){
     #Get pedigree data
     if(!exists("persons_ped1",envir=mmTK)){
@@ -269,31 +287,43 @@ relMixGUI <- function(){
     } else{
       contWindow <- gwindow("Contributors")
       contFrame <- gframe("Specify contributors in mixture",container=contWindow)
-      gcheckboxgroup(union(persons1,persons2), checked=FALSE,horizontal=FALSE,container=contFrame,
-                     handler=f_values,action="idxC")
-   
+      #Check if contributors have already been specified. If so, set these as checked boxes
+      if(!exists("idxC1",envir=mmTK)) idxC1 <- NULL
+      if(!exists("idxC2",envir=mmTK)) idxC2 <- NULL
+      else {
+        idxC1 <- get("idxC1",envir=mmTK)
+        idxC2 <- get("idxC2",envir=mmTK)
+      }
+      persons <- union(persons1,persons2)
+      #gcheckboxgroup(persons, checked=persons%in%idxC,horizontal=FALSE,container=contFrame,
+      #               handler=f_values,action="idxC")
       
-      # #Different contributors under each hypothesis
-      # contFrame <- gframe("Contributors in pedigree 1",container=contWindow)
-      # gcheckboxgroup(union(persons1,persons2), checked=FALSE,horizontal=FALSE,container=contFrame,
-      #                handler=f_values,action="idxC1")
-      # contFrame2 <- gframe("Contributors in pedigree 2",container=contWindow)
-      # gcheckboxgroup(union(persons1,persons2), checked=FALSE,horizontal=FALSE,container=contFrame2,
-      #                handler=f_values,action="idxC2")
+      
+      #Different contributors under each hypothesis
+      contFrame <- gframe("Contributors in pedigree 1",container=contWindow)
+      gcheckboxgroup(persons, checked=persons1%in%idxC1,horizontal=FALSE,container=contFrame,
+                     handler=f_values,action="idxC1")
+      contFrame2 <- gframe("Contributors in pedigree 2",container=contWindow)
+      gcheckboxgroup(persons, checked=persons2%in%idxC2,horizontal=FALSE,container=contFrame2,
+                     handler=f_values,action="idxC2")
       
       gbutton("ok", container=contWindow,handler=function(h,...){
         dispose(h$obj)
       })
     }
-   }
-
+  }
+  
   #Get mixture in the right format
   f_mixture <- function(E){
     m <- length(unique(E$Marker)) #Number of markers
-    #n <- length(unique(E$SampleName)) #Number of samples (if replicates)
-    mix <- split(E[,-c(1,2)],E$Marker) #Split according to markers
+    n <- length(unique(E$SampleName)) #Number of samples (if replicates)
+    #mix <- split(E[,-c(1,2)],E$Marker) #Split according to markers
+    #Split according to markers and then sample
+    mix <- split(E,E$Marker) 
+    mix2 <- lapply(mix,function(x) split(x[,-c(1,2)],x$SampleName))
     #Remove NA's
-    lapply(mix,function(x) x[!is.na(x)])
+    lapply(mix2,function(z) lapply(z, function(z2) z2[!is.na(z2)]))
+    #lapply(mix,function(x) x[!is.na(x)])
     #lapply(mix,function(x) { #Split according to sample (if replicates)
     #  x <- x[,!is.na(x),drop=F]
     #  split(x[-c(1,2)],x$SampleName)
@@ -306,7 +336,7 @@ relMixGUI <- function(){
     gt <- split(GT,GT$Marker) #Split according to markers
     lapply(gt,function(x) split(x[,3:4],x$SampleName)) #Split according to individual
   }
- 
+  
   #Add silent allele to database
   f_silent <- function(freqs,ps){
     
@@ -365,15 +395,15 @@ relMixGUI <- function(){
       mess <- paste("Allele",alNotDB, "will be added to marker",markerNames[keepIx], "with frequency",MAF)
       gmessage(mess, title="Note",icon = "info")
       # gconfirm(mess, title="Note",icon = "info",handler=function(h,...){ #Begin handler add alleles
-         #Add new allele at the end of database
-         newData <- data.frame(markerNames[keepIx],alNotDB,MAF)
-         colnames(newData) <- c('Marker','Allele','Frequency')
-         db <- data.frame(Marker=c(as.character(db$Marker),as.character(newData$Marker)),
-                          Allele=c(as.character(db$Allele),as.character(newData$Allele)),
-                          Frequency=c(db$Frequency,newData$Frequency))
-         assign('db',db,mmTK)
-         #Check for MAF, scale and sort
-         f_MAF(db,MAF)
+      #Add new allele at the end of database
+      newData <- data.frame(markerNames[keepIx],alNotDB,MAF)
+      colnames(newData) <- c('Marker','Allele','Frequency')
+      db <- data.frame(Marker=c(as.character(db$Marker),as.character(newData$Marker)),
+                       Allele=c(as.character(db$Allele),as.character(newData$Allele)),
+                       Frequency=c(db$Frequency,newData$Frequency))
+      assign('db',db,mmTK)
+      #Check for MAF, scale and sort
+      f_MAF(db,MAF)
       # }) #end handler add alleles
       
     } else{ #No alleles added to database
@@ -390,10 +420,10 @@ relMixGUI <- function(){
     db <- get('db',mmTK)
     if(any(db$Frequency<MAF)){ #Frequencies below MAF
       gconfirm("Some frequencies are below the min. allele frequency.
-          Change the indicated frequencies?", title="Note",icon = "question",handler = function(h,...){
-        db$Frequency[db$Frequency<MAF] <- MAF
-        assign('db',db,mmTK)
-      })
+               Change the indicated frequencies?", title="Note",icon = "question",handler = function(h,...){
+                 db$Frequency[db$Frequency<MAF] <- MAF
+                 assign('db',db,mmTK)
+    })
       
     }
     #Check if scaling is necessary
@@ -424,23 +454,37 @@ relMixGUI <- function(){
     sums <- sapply(1:length(markerNames),function(i) round(sum(db[db[,1]==markerNames[i],3]),4))
     ix <- which(sums!=1)
     if(length(ix)>0) { 
-      #TO DO: Add rest allele if no scaling. What do we do if sum > 1?
-      #Add rest allele
-      #mSums <- markerNames[ix]
-      #dbF <- rbind(db,data.frame(Marker=mSums,Allele='r',Frequency=1-sums[ix]))
-      #assign('dbF',dbF,envir=mmTK) #Final database if no scaling
-      gconfirm("Frequencies do not sum to 1. Do you want to scale?", title="Note",icon = "info",handler = function(h,...){
-        mSums <- markerNames[ix]
+      #gconfirm("Frequencies do not sum to 1. Do you want to scale?", title="Note",icon = "info",handler = function(h,...){
+      #   mSums <- markerNames[ix]
+      #   for(m in mSums){
+      #     db[db[,1]==m,3] <- db[db[,1]==m,3]/sum(db[db[,1]==m,3])
+      #   }
+      #   assign('dbF',db,envir=mmTK) #Final database
+      # })
+      
+      w <- gconfirm(format("Frequencies do not sum to 1. Do you want to scale? If not, a rest allele will be added.",jusity="centre"), title="Note",icon = "info")
+      mSums <- markerNames[ix]
+      if(svalue(w)){ #Scale
         for(m in mSums){
-          db[db[,1]==m,3] <- db[db[,1]==m,3]/sum(db[db[,1]==m,3])
+            db[db[,1]==m,3] <- db[db[,1]==m,3]/sum(db[db[,1]==m,3])
         }
-        assign('dbF',db,envir=mmTK) #Final database
-      })
+      } else{ #Rest allele, or scale if frequencies sum > 1
+            for(i in ix){
+                if(sums[i]>1) { #Enforce scaling
+                  db[db[,1]==m,3] <- db[db[,1]==m,3]/sum(db[db[,1]==m,3])
+                  mess <- paste("Enforced scaling for marker ",markerNames[sums[ix]>1])
+                  gmessage(mess, title="Note",icon = "info")
+                } else { #Rest allele
+                    db <- rbind(db,data.frame(Marker=mSums,Allele='r',Frequency=1-sums[i]))
+                }
+             }
+      }
+      assign('dbF',db,envir=mmTK) #Final database
     }
   }
   
-    
-
+  
+  
   f_LR <- function(){
     
     ####### Get input ########
@@ -452,14 +496,15 @@ relMixGUI <- function(){
     mutModel <- get("Mut",envir=mmTK)
     optPar <- get('optPar',mmTK)
     theta <- optPar$theta
-
+    
     #Profiles
     if(!exists('mixture',envir=mmTK)){ f_errorWindow("Mixture not imported"); stop()}
     if(!exists('reference',envir=mmTK)){ f_errorWindow("Reference profiles not imported"); stop()}
     if(!exists('frequencies',envir=mmTK)){ f_errorWindow("Missing allele frequencies"); stop()}
     if(!exists("ped1",envir=mmTK)){ f_errorWindow("Missing pedigree information"); stop()}
     if(!exists("ped2",envir=mmTK)){ f_errorWindow("Missing pedigree information"); stop()}
-    if(!exists("idxC",envir=mmTK)){ f_errorWindow("Contributors not specified"); stop()}
+    if(!exists("idxC1",envir=mmTK)){ f_errorWindow("Contributors not specified"); stop()}
+    
     
     E <- get("mixture",envir=mmTK) #get object
     G <- get("reference",envir=mmTK) #get object
@@ -472,10 +517,10 @@ relMixGUI <- function(){
     
     #Check if there are non-numeric allele names and stepwise mutation model
     #If so, give a warning
-    isNumeric <- suppressWarnings(as.numeric(alleleNames[-which(alleleNames=="Silent")]))
+    isNumeric <- suppressWarnings(as.numeric(alleleNames[alleleNames!="Silent"]))
     if(any(is.na(isNumeric)) && mutModel=='Stepwise'){
-      f_errorWindow("Stepwise mutation model require only numeric allele names. 
-                    Change allele names or choose a different mutation model.")
+      f_errorWindow(format("Stepwise mutation model requires numeric allele names. 
+                    Change allele names or choose a different mutation model.",justify="centre"))
     }
     
     # db2 <- numeric()
@@ -491,44 +536,52 @@ relMixGUI <- function(){
     #Make lists of alleles and frequencies per marker
     allelesAll <- split(db2$Allele,db2$Marker)
     afreqAll <- split(db2$Frequency,db2$Marker)
-
+    
     #Pedigree data
     ped1 <- get("ped1",envir=mmTK)
     ped2 <- get("ped2",envir=mmTK)
     persons1 <- get("persons_ped1",envir=mmTK)
     persons2 <- get("persons_ped2",envir=mmTK)
     pedigrees <- list(ped1,ped2)
-    idxC <- get("idxC",envir=mmTK) #Individuals who are contributors
+    #idxC <- get("idxC",envir=mmTK) #Individuals who are contributors
+    idxC1 <- get("idxC1",envir=mmTK) #Contributors under H1
+    idxC2 <- get("idxC2",envir=mmTK) #Contributors under H2
     idxK <- unique(G[,1]) #Individuals with known genotypes
-    idxU <- idxC[!idxC%in%idxK] #Contributors with uknown genotypes
-
+    idxC <- union(idxC1,idxC2)
+    idxU <- idxC[!idxC%in%idxK] #Contributors with uknown genotypes. Assuming that all individuals are represented in both pedigrees!
+    
     #Dropout/drop-in
-    #Set default dropout 0 for all contributors if
-    if(!exists('dropliste',envir=mmTK)){
-      dDef <- get('drop',envir=mmTK)
-      D <- rep(list(dDef$d),length(idxC))
-      names(D) <- idxC
-      di <- dDef$di
-    } else{
-      drop <- get('dropliste',mmTK)
+    #Set default dropout 0 for all contributors if none is set
+    # if(!exists('dropliste',envir=mmTK)){
+    #   dDef <- get('drop',envir=mmTK)
+    #   D <- rep(list(dDef$d),length(idxC))
+    #   names(D) <- idxC
+    #   di <- dDef$di
+    # } else{
+    drop <- get('dropliste',mmTK)
+    if(!all(idxC%in%names(drop))){ f_errorWindow("Specify dropout and drop-in"); stop()
+    } else {
       D <- drop[idxC]
       di <- drop[["dropin"]]
     }
     
-
+    
     ############# Computations ###########
     #infoWindowLR <- gwindow("",visible=TRUE)
     #glabel("Computing LR...",container=infoWindowLR)
     
     markers <- names(R)
     LRmarker <- numeric(length(markers))
+    lik1 <- lik2 <- numeric(length(markers))
     for(i in 1:length(R)){
       #Create locus object for each marker
       alleles <- as.character(allelesAll[[which(names(allelesAll)==markers[i])]])
       afreq <- afreqAll[[which(names(afreqAll)==markers[i])]]
+      #Set MutationRate2 to a very small number to avoid probability 0 of mutation to and from microinvariants
+      #This is same as is done in Familias (MutationRate2 will be ignored unless mutation model is stepwise)
       locus <- FamiliasLocus(frequencies=afreq,name=markers[i],
                              allelenames=alleles, MutationModel=mutModel, femaleMutationRate=r1,
-                             maleMutationRate=r2, MutationRange=range1)
+                             maleMutationRate=r2, MutationRange=range1, MutationRate2 = 1e-06)
       
       #If there is a silent allele we need to modify the mutation matrix.
       #Silent allele must be given as 's' (not 'silent' as in Familias)
@@ -543,52 +596,171 @@ relMixGUI <- function(){
       }
       
       datamatrix <- createDatamatrix(locus,knownGenos[[which(names(knownGenos)==markers[i])]],idsU=idxU)
-      names(pedigrees) <- c("Paternity","Unrelated")
-      res <- relMix(pedigrees, locus, R=R[[i]], datamatrix, ids=idxC, D=lapply(D,function(x) c(x,x^2)),di=di, kinship=theta)
-      LRmarker[i] <- res$Paternity/res$Unrelated
+      names(pedigrees) <- c("H1","H2")
+      
+      if(identical(idxC1,idxC2)){
+          res <- relMix(pedigrees, locus, R=R[[i]], datamatrix, ids=idxC, D=lapply(D[idxC],function(x) c(x,x^2)),di=di, kinship=theta)
+          lik1[i] <- res$H1
+          lik2[i] <- res$H2
+          
+      } else {
+        #relMix must be run twice with different contributors specified
+        #Since we assume that all individuals are represented in all pedigrees, we have the same datamatrix under both hypotheses
+        res1 <- relMix(pedigrees$H1, locus, R=R[[i]], datamatrix, ids=idxC1, D=lapply(D[idxC1],function(x) c(x,x^2)),di=di, kinship=theta)
+        res2 <- relMix(pedigrees$H2, locus, R=R[[i]], datamatrix, ids=idxC2, D=lapply(D[idxC2],function(x) c(x,x^2)),di=di, kinship=theta)
+        lik1[i] <- res1[[1]]
+        lik2[i] <- res2[[1]]
+      }
+      
     }
+    LRmarker <- lik1/lik2
     
     #dispose(infoWindowLR)
     
-    #Data <- data.frame(Marker=c(markers,"Total"),LR=c(LRmarker,prod(LRmarker)))
-    Data <- data.frame(Marker=markers,LR=round(LRmarker,4))
-    LRwindow <- gwindow("Results",visible=FALSE)
-    LRgroup1 <- ggroup(horizontal=FALSE,container=LRwindow)
-    glabel(paste("Total LR:",format(prod(LRmarker),,scientific=TRUE)),container=LRgroup1)
-    LRgroup2 <- ggroup(container=LRwindow)
-    tab <- gtable(Data,container=LRgroup2)
-    LRbut <- gbutton("Save LR to file", container=LRwindow,handler=function(h,...){
-      f_export(rbind(Data,data.frame(Marker="Total",LR=format(prod(LRmarker),scientific=TRUE))))
+    Data <- data.frame(Marker=markers,LR=LRmarker,LikH1=lik1,LikH2=lik2,stringsAsFactors=FALSE)
+    
+    #Make result window
+    LRwindow <- gwindow("Results",height=800,width=800,visible=FALSE,horizontal=TRUE)
+    LRgroup1 <- ggroup(horizontal = TRUE, container=LRwindow)
+    
+    paramGroup <- ggroup(horizontal=FALSE,container=LRgroup1)
+    #size(paramGroup) <- c(250,450)
+    
+    #Database options
+    databaseData <- data.frame(Parameter=c("theta","Silent allele freq.","Min. allele freq."),Value=unlist(optPar))
+    databaseData[,1] <- as.character(databaseData[,1])
+    databaseData[,2] <- as.character(databaseData[,2])
+    
+    
+    databaseGroup <- ggroup(horizontal=FALSE,container=paramGroup)
+    databaseFrame <- gframe("Database",container=databaseGroup,horizontal=FALSE)
+    #dataTab <- gtable(databaseData,container=databaseFrame)
+    dataTab <- gtable(format(databaseData, justify = "centre"),container=databaseFrame)
+    size(dataTab) <- list(height=110,width=240,columnWidths=c(120,50))
+    
+    #Mutations
+    if(mutModel=="Stepwise"){
+      mutData <- data.frame(Parameter=c("Model","Range"),Value=c(mutModel,mutPar$mutRange))
+    } else mutData <-  data.frame(Parameter="Model",Value=mutModel)
+    mutData2 <- data.frame(Parameter=c("Female mut. rate","Male mut. rate"),Value=c(mutPar$fMutRate,mutPar$mMutRate))
+    mutData[,1] <- as.character(mutData[,1])
+    mutData2[,1] <- as.character(mutData2[,1])
+    mutData[,2] <- as.character(mutData[,2])
+    mutData2[,2] <- as.character(mutData2[,2])
+    mutData <- rbind(mutData,mutData2)
+    
+    mutGroup <- ggroup(horizontal=FALSE,container=paramGroup)
+    mutFrame <- gframe("Mutations",container=mutGroup,horizontal=FALSE)
+    #mutTab <- gtable(mutData,container=mutFrame)
+    mutTab <- gtable(format(mutData, justify = "centre"),container=mutFrame)
+    size(mutTab) <- list(height=110,width=240,columnWidths=c(120,50))
+    
+    contGroup <- ggroup(horizontal=FALSE,container=paramGroup)
+    contFrame <- gframe("Contributors",container=contGroup,horizontal=FALSE)
+    if(length(idxC1)<length(idxC2)){
+      contData <- cbind("Pedigree 1"=idxC1[seq(idxC2)],"Pedigree 2"=idxC2)
+    } else{
+      contData <- cbind("Pedigree 1"=idxC1,"Pedigree 2"=idxC2[seq(idxC1)])
+    }
+    contData[is.na(contData)] <- ""
+    contTab <- gtable(format(as.data.frame(contData), justify = "centre"),container=contFrame)
+    size(contTab) <- list(height=90,width=240,columnWidths=c(85,85))
+    
+    #ggraphics(ps=6, container=contFrame)
+    #plot()
+    
+    #Dropout/drop-in
+    dropData <- data.frame(Parameter=c(paste("Dropout",names(D)),"Drop-in"),Value=c(unlist(D),di))
+    dropData[,1] <- as.character(dropData[,1])
+    dropData[,2] <- as.character(dropData[,2])
+    colnames(dropData) <- c("Parameter","Value")
+    dropGroup <-  ggroup(horizontal=FALSE,container=paramGroup,spacing=7)
+    dropFrame <- gframe("Dropout and drop-in",container=dropGroup,horizontal=FALSE)
+    dropTab <- gtable(format(dropData,justify="centre"),container=dropFrame)
+    size(dropTab) <- list(height=110,width=240,columnWidths=c(120,50))
+    
+    
+    LRgroup2 <- ggroup(container=LRgroup1,horizontal=FALSE,spacing=7)
+    glabel(paste("Total LR:",format(prod(LRmarker),digits=4,scientific=TRUE)),container=LRgroup2)
+    tab <- gtable(format(Data[,1:2],digits=4,scientific=TRUE),container=LRgroup2)
+    #size(tab) <- list(width=200,columnWidths=c(10,50))
+    
+    
+    #Prepare data to write to file
+    allParam <- rbind(databaseData,mutData,dropData)
+    colnames(contData) <- paste("Contributors",colnames(contData))
+    allParam <- cbind(allParam," "=rep("",nrow(allParam)),rbind(contData,matrix("",nrow=nrow(allParam)-nrow(contData),ncol=ncol(contData))))
+    #exportData <- data.frame(c(allParam[,1],"","Marker",Data[,1],"Total"),c(allParam[,2],"","LR",Data[,2],prod(LRmarker)),
+    #                         c(rep("",nrow(allParam)+1),"Lik H1",Data[,3],prod(Data[,3])),c(rep("",nrow(allParam)+1),"Lik H2",Data[,4],prod(Data[,4])))
+    #Parameters and LR
+    #paramLR <- data.frame(c(allParam[,1],"","Marker",Data[,1],"Total"),c(allParam[,2],"","LR",Data[,2],prod(LRmarker)),
+    #                         c(rep("",nrow(allParam)+1),"Lik H1",Data[,3],prod(Data[,3])),c(rep("",nrow(allParam)+1),"Lik H2",Data[,4],prod(Data[,4])))
+    
+    #Reference profiles
+    gtlist <- split(G[,3:4],G[,1])
+    GT <- do.call(cbind,gtlist)
+    #Mixture profile
+    mix <- E[-1]
+    colnames(mix) <- c("Marker",paste("Mix.",colnames(mix[,-1]),sep=""))
+    GT <- GT[rep(1:nrow(GT),length(unique(E$SampleName))),]
+    rownames(GT) <- rownames(E)
+    prof <- cbind(E,GT)
+    prof[is.na(prof)] <- ""
+    
+    #LRgt <- cbind(rbind(Data,c("Total",prod(LRmarker),prod(Data[,3]),prod(Data[,4]))),rbind(prof[,-1],rep("",ncol(prof)-1)))
+    DataTot <- rbind(Data,c("Total",prod(LRmarker),prod(Data[,3]),prod(Data[,4])))
+    fill <- matrix("",nrow=nrow(DataTot),ncol=ncol(prof)-ncol(DataTot))
+    DataTot <- cbind(DataTot,fill)
+    colNames <- c(colnames(Data),rep(" ",ncol(fill)))
+    colNamesFill <- rbind(rep("",length(colNames)),colNames)
+    colnames(colNamesFill) <- colnames(DataTot)
+    DataTot <- rbind(colNamesFill,DataTot)
+    
+    colnames(DataTot) <- colnames(prof)
+    LRgt <- rbind(prof,DataTot)
+    #LRgt <- rbind(rbind(Data,c("Total",prod(LRmarker),prod(Data[,3]),prod(Data[,4]))),rbind(prof[,-1],rep("",ncol(prof)-1))))
+    LRgt <- rbind(colnames(LRgt),LRgt)
+    fill <- matrix("",nrow=nrow(allParam),ncol=ncol(LRgt)-ncol(allParam))
+    allParam2 <- rbind(cbind(allParam,fill),rep("",ncol(LRgt)))
+    colnames(LRgt) <- colnames(allParam2)
+    exportData <- rbind(allParam2,LRgt)
+    exportData[is.na(exportData)] <- ""
+    rownames(exportData) <- NULL
+    colnames(exportData) <- c("Parameter","Value","",colnames(contData),rep("",ncol(exportData)-5))
+    
+    LRbut <- gbutton("Save results to file", container=LRgroup2,handler=function(h,...){
+      f_export(exportData)
       dispose(h$obj)
     })
+    
     visible(LRwindow) <- TRUE
-  }
-
-
+    }
+  
+  
   ############################################################
-
+  
   mmTK = new.env() #create new environment object
-
+  
   #Assign some default parameters
   defaultList <- list(Mut='Equal',
-                    mutPar=list(mutRange=0.5,
-                              fMutRate=0,
-                              mMutRate=0),
-                    optPar=list(theta=0,
-                                silent=0,
-                                MAF=0.001),
-                    drop=list(d=0,
-                              di=0)
-                    )
+                      mutPar=list(mutRange=0.5,
+                                  fMutRate=0,
+                                  mMutRate=0),
+                      optPar=list(theta=0,
+                                  silent=0,
+                                  MAF=0.001),
+                      dropliste=list(d=0.00,
+                                     di=0.00)
+  )
   
   for(i in 1:length(defaultList)){
     assign(names(defaultList)[i],defaultList[[i]],envir=mmTK)
   }
- 
-
+  
+  
   win <- gwindow("RelMix",height=500,width=500,visible=FALSE)
   group1 <- ggroup(horizontal = TRUE, container=win,spacing=10)
-
+  
   ###### Import data #####
   #Buttons for importing files
   dataGroup <- ggroup(horizontal = FALSE, container=group1,spacing=7)
@@ -596,15 +768,15 @@ relMixGUI <- function(){
   objMix <- gbutton(text="Import mixture profile",container=impFrame,handler=f_importprof,action="mixture")
   objRef <- gbutton(text="Import reference profiles",container=impFrame,handler=f_importprof,action="reference")
   objRef <- gbutton(text="Database",container=impFrame,handler=f_database)
-
+  
   ###### Mutations #####
   #Mutation frame
   mutFrame <- gframe("Mutations",container=group1,horizontal=FALSE,spacing=7)
   mutGroup <- ggroup(horizontal = FALSE, container=mutFrame,spacing=7)
   mutButton <- gbutton("Mutations", handler=f_mutations, container=mutGroup)
-
+  
   group2 <- ggroup(horizontal = TRUE, container=win,spacing=10)
-
+  
   ####### Pedigrees ######
   #Pedigree frame
   pedGroup <- ggroup(horizontal = FALSE, container=group2,spacing=7)
@@ -616,24 +788,24 @@ relMixGUI <- function(){
   #Pedigree 2 button
   glabel("Pedigree 2",container=pedFrame)
   objPed2 <- gcombobox(c("Paternity","Unrelated","Custom"), selected=0,container=pedFrame,handler=f_pedigree,action="2")
-
+  
   ######## Contributors #######
   contFrame <- gframe("Contributors",container=group2,horizontal=TRUE)
   objCont <- gbutton(text="Specify contributors",container=contFrame,handler=f_contributors)
-
+  
   ######## Dropout/drop-in #########
   group3 <- ggroup(horizontal = TRUE, container=win,spacing=10)
   #Dropout button
   dropFrame <- gframe("Dropout and drop-in",container=group3,horizontal=TRUE)
   dropButton <- gbutton("Specify dropout and drop-in", handler=f_dropout, container=dropFrame)
-
+  
   ####### Compute LR ######
   group4 <- ggroup(horizontal = TRUE, container=win,spacing=10)
   #Compute LR button
   LRbutton <- gbutton("Compute LR", container=group4, handler=function(h,...){
     f_LR()
-    })
-
+  })
+  
   visible(win) <- TRUE
 }
 
